@@ -68,7 +68,7 @@ centipede.plot<-function(segs,mct="mean",lower.limit="std.error",
  }
  else seg.order<-1:segdim[1]
  oldpar<-par("mar")
- if(is.na(mar)) mar<-c(4,6,1+2*(nchar(main)>0),5)
+ if(is.na(mar[1])) mar<-c(4,6,1+2*(nchar(main)>0),5)
  par(mar=mar)
  plot(x=c(min(segs[2,]),max(segs[3,])),y=c(1,segdim[2]), 
   main=main,xlab="",ylab="",type="n",axes=FALSE,...)
